@@ -1,7 +1,7 @@
 # TRUE if leap year, FALSE otherwise
 leapyear <- function(y) {
 	
-	res <- .C("leapyear",year=as.integer(y),ly=integer(1),PACKAGE="pheno")
+	res <- .C("Cleapyear",year=as.integer(y),ly=integer(1),PACKAGE="pheno")
 
 	if(res$ly==1) { return(TRUE)}
 	else { return(FALSE)}
