@@ -15,20 +15,20 @@
 /**   This code is subject to the GNU PUBLIC LICENSE 2 or higher	         **/
 /******************************************************************************/
 
-void date2jul1(char *date[], int *doy, int *year);
+void Cdate2jul1(char *date[], int *doy, int *year);
 
-void date2jul2(int *year, int *month, int *day, int *doy);
+void Cdate2jul2(int *year, int *month, int *day, int *doy);
 
-void daysbetween(char *date1[], char *date2[], int *ndays);
+void Cdaysbetween(char *date1[], char *date2[], int *ndays);
 
-void daylength(double *lat, int *iday, double *dl, double *delta);
+void Cdaylength(double *lat, int *iday, double *dl, double *delta);
 
-void jul2date1(int *doy, int *year, char *date[]);
+void Cjul2date1(int *doy, int *year, char *date[]);
 
-void jul2date2(int *doy, int *year, int *day, int *month);
+void Cjul2date2(int *doy, int *year, int *day, int *month);
 
-void leapyear(int *year, int *ly);
+void Cleapyear(int *year, int *ly);
 
-void maxdaylength(double *lat, double *maxdl);
+void Cmaxdaylength(double *lat, double *maxdl);
 
-void connectivity(double tmp[],int *maxnr,int *maxnc,int row_classes[],int col_clases[]);
+void Cconnectivity(double tmp[],int *maxnr,int *maxnc,int row_classes[],int col_clases[]);
